# libpythonpro
Modulo para exemplificar construćão de projetos Python

Link para o curso [Python.Pro](https://www.python.pro.br/)

[![Build Status](https://travis-ci.org/limberger/libpythonpro.svg?branch=master)](https://travis-ci.org/limberger/libpythonpro)
[![Updates](https://pyup.io/repos/github/limberger/libpythonpro/shield.svg)](https://pyup.io/repos/github/limberger/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/limberger/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/limberger/libpythonpro/)
S
uporta versão 3 de Python

para instalar:

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade do código:

```console
flake8
```

